@@ -37,7 +37,7 @@ class Warehut:
         self.consumers.extend(self.hybrids)
         self.producers.extend(self.hybrids)
 
-        self.workers = self.producers + self.consumers + self.hybrids
+        self.workers = list(set(self.producers + self.consumers))
 
 
     def __enter__(self):
